import { fabric } from 'fabric';
import Handler from './Handler';
/**
 * 全局的图层处理器
 */
declare class LayerHandler {
    /** @ignore */
    handler: Handler;
    /**
     * 画布上的全部图层列表
     */
    private layerList;
    /**
     * 画布上的有效图层列表，即不包含最底层workarea、最顶层work_mask的其他图层
     */
    private effectiveLayerList;
    /** @ignore */
    constructor(handler: Handler);
    /**
     * 获取画布上的图层
     */
    private getLayers;
    /**
     * 获取画布上的全部图层
     */
    getAllLayers(): fabric.Object[];
    /**
     * 获取画布上的有效图层，即除workarea/work_mask之外的图层
     */
    getEffectiveLayers(): fabric.Object[];
    /**
     * 移动元素
     * @param direct 1向上移动 -1向下移动
     * @param obj 被移动的元素，不传入时默认画布中当前选择的元素
     * @returns
     */
    updateLayerOrderByDirect(direct: -1 | 1, obj?: fabric.Object): void;
    /**
     * 移动元素到指定图层
     * @param target 想要移动到的图层index
     * @param moveInEffectiveLayer 是否在有效图层中移动，默认为是
     * @param obj 被移动的元素，不传入时默认画布中当前选择的元素
     * @returns
     */
    updateLayerOrderByTargetIndex(target: number, moveInEffectiveLayer?: boolean, obj?: fabric.Object): boolean;
    /**
     * 获取元素所在的层级
     * @param object 元素
     * @returns 层级
     */
    getLayer(object?: fabric.Object): number;
}
export default LayerHandler;
